.. include:: ../../README.rst
   :end-before: .. substitutions

.. toctree::
   :hidden:
   :maxdepth: 2

   Home <self>
   api
   changelog

.. |banner| image:: /_images/BlueBrainSNAP.jpg
.. |circuit| replace:: :class:`.Circuit`
.. |simulation| replace:: :class:`.Simulation`
